Open various data exploration and analysis applications hosted by the ILO.
Usage
runapp_ilostat(name = "dataexplorer")
Arguments
name
`chr` The name of the application to open.
Available applications:
"dataexplorer": Quickly find, filter, pivot, and download ILOSTAT data.
"microquery": Explore data availability and create custom queries from the ILO Harmonized Microdata Collection. Users can select variables, filters, and indicators to generate tailored datasets.
"regionalaggregate": Generate custom regional estimates by defining or selecting country groupings. The app automatically aggregates country-level modelled data for selected indicators.
if (FALSE) {
runapp_ilostat(name = "dataexplorer")
# You can also run other apps like: runapp_ilostat(name = "microquery")
runapp_ilostat(name = "regionalaggregate")
}